## General Todos:
- prompts can still be optimized for better results given that some games like sudoku, wordsearch, and logic puzzles are still challenging for GPT-4o-mini.

## Remaining Games
- sudoku **Bobby** [Done]
- crosswords **Bobby** [Done]
- chess (against bot) **leon** 
- car puzzle **leon**
- connect four **leon**
- hangman **Bobby** [Done]
- word ladder **Bobby** [Done]
- guess the number **Bobby** [Done]
- word search Players find hidden words within a grid of letters presented in text format. **Bobby** [Done]
- logic puzzles **Bobby** [Done]
- fifteen puzzle A sliding puzzle that consists of a frame of numbered square tiles in random order with one tile missing. **Bobby** [Done]
- Tower of Hanoi **Bobby** [Done]
- Minesweeper **Bobby** [Done]

GPT 
- 20 questions **bobby** [Done]
- Guess Who **bobby** [done]